 py4tga

[![image](https://img.shields.io/pypi/v/py4tga.svg)](https://pypi.python.org/pypi/py4tga)

[![image](https://img.shields.io/travis/rahulrameshnair/py4tga.svg)](https://travis-ci.com/rahulrameshnair/py4tga)

[![Documentation Status](https://readthedocs.org/projects/py4tga/badge/?version=latest)](https://py4tga.readthedocs.io/en/latest/?version=latest)

Python for thermogravimetry analysis

-   Free software: MIT license
-   Documentation: <https://py4tga.readthedocs.io>. (not added yet)

## Features

-   TODO

## Credits

This package was created with
[Cookiecutter](https://github.com/audreyr/cookiecutter) and the
[audreyr/cookiecutter-pypackage](https://github.com/audreyr/cookiecutter-pypackage)
project template.